import request from '@/utils/request'

// 查询参数列表
export function listConfig(query) {
  return request({
    url: '/system/config/list',
    method: 'get',
    params: query
  })
}

// 查询在谈线索信息
export function listConfigtwo(query) {
  return request({
    url: '/projectInfo/info/' + query,
    method: 'get'
    // params:
  })
}
export function listConfigthert(query) {
  return request({
    url: '/projectInvestor/investor/list',
    method: 'get'
    // params:
  })
}
export function listConfigfour(query) {
  return request({
    url: '/projectPersion/persion/list',
    method: 'get'
    // params:
  })
}
//字典
export function listConfigther(query) {
  return request({
    url: '/system/dict/data/type/project_status',
    method: 'get'
    // params:
  })
}
export function listConfigfive(query) {
  return request({
    url: '/projectConstruction/construction/' +query,
    method: 'get'
    // params:
  })
}
export function listConfigsix(query) {
  return request({
    url: '/constructionRate/rate/list',
    method: 'get'
    // params:
  })
}

// 查询参数详细
export function getConfig(configId) {
  return request({
    url: '/projectInvestor/investor/' + configId,
    method: 'get'
  })
}

// 根据参数键名查询参数值
export function getConfigKey(configKey) {
  return request({
    url: '/system/config/configKey/' + configKey,
    method: 'get'
  })
}

export function getConfigKeytwo(configKey) {
  return request({
    url: '/projectPersion/persion/' + configKey,
    method: 'get'
  })
}

// 新增参数配置
export function addConfig(data) {
  return request({
    url: '/projectInvestor/investor',
    method: 'post',
    data: data
  })
}
export function addConfigtwo(data) {
  return request({
    url: '/projectPersion/persion',
    method: 'post',
    data: data
  })
}

// 修改参数配置
export function updateConfig(data) {
  return request({
    url: '/projectInvestor/investor',
    method: 'put',
    data: data
  })
}
export function updateConfigtwo(data) {
  return request({
    url: '/projectPersion/persion',
    method: 'put',
    data: data
  })
}

// 删除参数配置
export function delConfig(configId) {
  return request({
    url: '/projectInvestor/investor/' + configId,
    method: 'delete'
  })
}
export function delConfigtwo(configId) {
  return request({
    url: '/projectPersion/persion/' + configId,
    method: 'delete'
  })
}
// 清理参数缓存
export function clearCache() {
  return request({
    url: '/system/config/clearCache',
    method: 'delete'
  })
}

// 导出参数
export function exportConfig(query) {
  return request({
    url: '/system/config/export',
    method: 'get',
    params: query
  })
}
